Learn R Programming

EMOTIONS (version 1.1)

BMAweight_gamma: Estimate normalized model`s weights based on a Expectation–Maximization (EM) algorithm using a gamma distribution

Description

Estimate normalized model`s weights based on a Expectation–Maximization (EM) algorithm using a gamma distribution

Usage

BMAweight_gamma(converged_models, x, trait)

Value

A vector containing the model normalized weight based on the Bayeasian Model Average (BMA) appaoch proposed by Duan et al. (2006) with an adaptation for to use a gamma distribution

Arguments

converged_models

A list containing the fitted models for the individual

x

data frame containing the daily milking records for the individual

trait

The name of the column containing daily milking records