Estimate normalized model`s weights based on a Expectation–Maximization (EM) algorithm using a gamma distribution
BMAweight_gamma(converged_models, x, trait)A vector containing the model normalized weight based on the Bayeasian Model Average (BMA) appaoch proposed by Duan et al. (2006) with an adaptation for to use a gamma distribution
A list containing the fitted models for the individual
data frame containing the daily milking records for the individual
The name of the column containing daily milking records